@@ -9,14 +9,16 @@ VERSION_FILE="./version"
 
 export GOWORK=off
 
-#is_source_build=$(git status > /dev/null 2>&1 && echo "1" || true)
-
+has_git=$(git status > /dev/null 2>&1 && echo "1" || true)
+tools_file="../tools/build/compute_version.go"
 # Handle vendoring and version detection
-#if [ -n "${is_source_build}" ]; then
-#    go run ../tools/build/compute_version.go > ${VERSION_FILE}
-#    rm -r vendor &> /dev/null || true
-#    go mod vendor
-#fi
+if [ -n "${has_git}" ]; then
+    if [ -r "${tools_file}" ]; then
+       go run ../tools/build/compute_version.go > ${VERSION_FILE}
+    fi
+   rm -r vendor &> /dev/null || true
+   go mod vendor
+fi
 
 version=$(cat ${VERSION_FILE})
-echo -ldflags=-X=github.com/canonical/ubuntu-pro-for-wsl/wsl-pro-service/internal/consts.Version=${version}
+echo -ldflags=-X=github.com/canonical/ubuntu-pro-for-wsl/wsl-pro-service/internal/consts.Version=${version} --mod=vendor
